4Suite API Documentation: Ft.Xml.XPath.ParsedStep

4Suite™ API Documentation

# ► Module Ft.Xml.XPath.ParsedStep

A parsed token that represents a step.

    Copyright 2004 Fourthought, Inc. (USA).
    Detailed license and copyright information: http://4suite.org/COPYRIGHT
    Project home, documentation, distributions: http://4suite.org/

Classes: ParsedAbbreviatedStep, ParsedNodeSetFunction, ParsedStep

## Classes

class ParsedAbbreviatedStep

  ### Methods

  __init__(self, parent)
  __repr__(self)
  __str__(self)
  evaluate(self, context)
  pprint(self, indent='')
  select = evaluate(self, context)
class ParsedNodeSetFunction
  # From the XPath 2.0 Working Draft # Used by XPointer

  ### Methods

  __init__(self, function, predicates=None)
  __repr__(self)
  __str__(self)
  evaluate(self, context)
    Select a set of nodes from the node-set function then filter through the predicates.
  pprint(self, indent='')
  select = evaluate(self, context)
    Select a set of nodes from the node-set function then filter through the predicates.
class ParsedStep

  ### Methods

  __init__(self, axis, nodeTest, predicates=None)
  __repr__(self)
  __str__(self)
  evaluate(self, context)
    Select a set of nodes from the axis, then filter through the node test and the predicates.
  pprint(self, indent='')
  select = evaluate(self, context)
    Select a set of nodes from the axis, then filter through the node test and the predicates.